@@ -301,6 +301,9 @@ class CliArgs(object):
             type=comma_separated_arg, action='extend',
             help='include rules whose id match these values'
         )
+        standard.add_argument(
+            '-e', '--include-experimental', help='Include experimental rules', action='store_true'
+        )
 
         advanced.add_argument(
             '-o', '--override-spec', dest='override_spec',
@@ -319,6 +322,10 @@ class CliArgs(object):
             '--update-documentation', help=argparse.SUPPRESS,
             action='store_true'
         )
+        advanced.add_argument(
+            '--update-iam-policies', help=argparse.SUPPRESS,
+            action='store_true'
+        )
 
         return parser
 
@@ -397,6 +404,11 @@ class ConfigMixIn(TemplateArgs, CliArgs, ConfigFileArgs, object):
         """ include_checks """
         return self._get_argument_value('include_checks', True, True)
 
+    @property
+    def include_experimental(self):
+        """ include_experimental """
+        return self._get_argument_value('include_experimental', True, True)
+
     @property
     def regions(self):
         """ regions """
@@ -508,6 +520,11 @@ class ConfigMixIn(TemplateArgs, CliArgs, ConfigFileArgs, object):
         """ update_specs """
         return self._get_argument_value('update_documentation', False, False)
 
+    @property
+    def update_iam_policies(self):
+        """ update_iam_policies """
+        return self._get_argument_value('update_iam_policies', False, False)
+
     @property
     def listrules(self):
         """ listrules """
